from django import template
from ..context import VueContext

register = template.Library()


@register.inclusion_tag('script.html', name='vue')
def vue(vue_ctx):
    if not isinstance(vue_ctx, VueContext):
        raise TypeError("Argument to 'vue' template must be a VueContext")

    return vue_ctx._to_render()



from os.path import join


class VueContext():

    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)
        self.data = {}
        self.scripts = []
        self.static_base = join('build', 'js')

    def set_data(self, key, val):
        """ Sets some data to be served to the Vue app """
        self.data[key] = val

    def add_script(self, script_loc):
        """ Add a static JS script to include in the page as well """
        self.scripts.append(script_loc)

    def _to_render(self):
        """ Return a dictionary to use to render the template """
        # TODO: Make it '.min.js' for prod
        script_suffix = '.umd.js'
        obj = {
            'data': self.data,
            'scripts': self.scripts,
            'script_locs': [
                join(
                    self.static_base,
                    sc + script_suffix
                ) for sc in self.scripts
            ],
        }
        return obj



import re
import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

with open('pointofvue/__init__.py', 'r') as fd:
    version = re.search(r'^__version__\s*=\s*[\'"]([^\'"]*)[\'"]',
                        fd.read(), re.MULTILINE).group(1)

reqs = [
]

setuptools.setup(
    name="pointofvue",
    version=version,
    author="Matt Dodge",
    author_email="mattedgod@gmail.com",
    description="A simple, opinionated way to incorporate VueJS into Django apps",
    long_description=long_description,
    long_description_content_type="text/markdown",
    install_requires=reqs,
    url="https://github.com/mattdodge/PointOfVue",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
)
